.. _upgrade-to-3.6.0:

###################
3.6.0 release notes
###################

This release of django CMS concentrates on introducing support for Django 2.0
and Django 2.1, and dropping support for Django versions lower than 1.11.


*******************
What's new in 3.6.0
*******************

Improvements and new features
=============================

* introduced support for Django 2.0
* introduced support for Django 2.1
* removed support for Django versions older than 1.11
* added ``page_title`` parameter for ``cms.api.create_page()`` and ``cms.api.create_title()``
* length restriction for ``Title.meta_description`` was moved from model to form; field length was
  increased to 320 characters.


Removal of deprecated functionality
===================================

Previously deprecated functionality has been removed:

* Signal handlers for ``Page``, ``Title``, ``Placeholder`` and ``CMSPlugin`` models was removed.
* Removed the ``cms moderator`` command.
* Removed the translatable content ``get``/``set`` methods from ``CMSPlugin`` model.


*********************
How to upgrade to 3.6
*********************

We assume you are upgrading from django CMS 3.5.

Please make sure that your current database is consistent and in a healthy
state, and **make a copy of the database before proceeding further.**

Then run::

    python manage.py migrate  # to ensure that your database is up-to-date with migrations
    python manage.py cms fix-tree

Check custom code and third-party applications for use of deprecated or removed functionality or
APIs (see above). Some third-party components may need to be updated.

Install the new version of django CMS from GitHub or via pip.

Run::

    python manage.py migrate

to apply the new migrations.


***********************************
Create a new django CMS 3.6 project
***********************************

On the Divio Cloud
==================

The Divio Cloud offers an easy way to set up django CMS projects. In the `Divio Cloud Control Panel
<https://control.divio.com>`_, create a new django CMS project and **Deploy** it.


Using the django CMS Installer
==============================

..  note::

    The django CMS Installer is not yet available for django CMS 3.6 or Django 2 or later.

    This section will be updated or removed before the final release of django CMS 3.6.


****************************
Contributors to this release
****************************

* Daniele Procida
* Vadim Sikora
* Paulo Alvarado
* Bartosz Płóciennik
* Katie McLaughlin
* Krzysztof Socha
* Mateusz Kamycki
* Sergey Fedoseev
* Aliaksei Urbanski
* heppstux
* Chematronix
* Frank
* Jacob Rief
* Julz
